import { Account, Context, Option, Pda, PublicKey, RpcAccount, RpcGetAccountOptions, RpcGetAccountsOptions, Serializer } from '@metaplex-foundation/umi';
import { MembershipModel, MembershipModelArgs } from '../types';
export type Fanout = Account<FanoutAccountData>;
export type FanoutAccountData = {
    discriminator: Array<number>;
    authority: PublicKey;
    name: string;
    accountKey: PublicKey;
    totalShares: bigint;
    totalMembers: bigint;
    totalInflow: bigint;
    lastSnapshotAmount: bigint;
    bumpSeed: number;
    accountOwnerBumpSeed: number;
    totalAvailableShares: bigint;
    membershipModel: MembershipModel;
    membershipMint: Option<PublicKey>;
    totalStakedShares: Option<bigint>;
};
export type FanoutAccountDataArgs = {
    authority: PublicKey;
    name: string;
    accountKey: PublicKey;
    totalShares: number | bigint;
    totalMembers: number | bigint;
    totalInflow: number | bigint;
    lastSnapshotAmount: number | bigint;
    bumpSeed: number;
    accountOwnerBumpSeed: number;
    totalAvailableShares: number | bigint;
    membershipModel: MembershipModelArgs;
    membershipMint: Option<PublicKey>;
    totalStakedShares: Option<number | bigint>;
};
export declare function getFanoutAccountDataSerializer(context: Pick<Context, 'serializer'>): Serializer<FanoutAccountDataArgs, FanoutAccountData>;
export declare function deserializeFanout(context: Pick<Context, 'serializer'>, rawAccount: RpcAccount): Fanout;
export declare function fetchFanout(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Fanout>;
export declare function safeFetchFanout(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Fanout | null>;
export declare function fetchAllFanout(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Fanout[]>;
export declare function safeFetchAllFanout(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Fanout[]>;
export declare function getFanoutGpaBuilder(context: Pick<Context, 'rpc' | 'serializer' | 'programs'>): import("@metaplex-foundation/umi").GpaBuilder<Fanout, {
    discriminator: Array<number>;
    authority: PublicKey;
    name: string;
    accountKey: PublicKey;
    totalShares: number | bigint;
    totalMembers: number | bigint;
    totalInflow: number | bigint;
    lastSnapshotAmount: number | bigint;
    bumpSeed: number;
    accountOwnerBumpSeed: number;
    totalAvailableShares: number | bigint;
    membershipModel: MembershipModelArgs;
    membershipMint: Option<PublicKey>;
    totalStakedShares: Option<number | bigint>;
}>;
export declare function getFanoutSize(): number;
export declare function findFanoutPda(context: Pick<Context, 'eddsa' | 'programs' | 'serializer'>, seeds: {
    name: string;
}): Pda;
