"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findFanoutPda = exports.getFanoutSize = exports.getFanoutGpaBuilder = exports.safeFetchAllFanout = exports.fetchAllFanout = exports.safeFetchFanout = exports.fetchFanout = exports.deserializeFanout = exports.getFanoutAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getFanoutAccountDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['authority', s.publicKey()],
        ['name', s.string()],
        ['accountKey', s.publicKey()],
        ['totalShares', s.u64()],
        ['totalMembers', s.u64()],
        ['totalInflow', s.u64()],
        ['lastSnapshotAmount', s.u64()],
        ['bumpSeed', s.u8()],
        ['accountOwnerBumpSeed', s.u8()],
        ['totalAvailableShares', s.u64()],
        ['membershipModel', (0, types_1.getMembershipModelSerializer)(context)],
        ['membershipMint', s.option(s.publicKey())],
        ['totalStakedShares', s.option(s.u64())],
    ], { description: 'Fanout' }), (value) => ({
        ...value,
        discriminator: [198, 246, 243, 191, 206, 255, 3, 247],
    }));
}
exports.getFanoutAccountDataSerializer = getFanoutAccountDataSerializer;
function deserializeFanout(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getFanoutAccountDataSerializer(context));
}
exports.deserializeFanout = deserializeFanout;
async function fetchFanout(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'Fanout');
    return deserializeFanout(context, maybeAccount);
}
exports.fetchFanout = fetchFanout;
async function safeFetchFanout(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists ? deserializeFanout(context, maybeAccount) : null;
}
exports.safeFetchFanout = safeFetchFanout;
async function fetchAllFanout(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'Fanout');
        return deserializeFanout(context, maybeAccount);
    });
}
exports.fetchAllFanout = fetchAllFanout;
async function safeFetchAllFanout(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeFanout(context, maybeAccount));
}
exports.safeFetchAllFanout = safeFetchAllFanout;
function getFanoutGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({
        discriminator: [0, s.array(s.u8(), { size: 8 })],
        authority: [8, s.publicKey()],
        name: [40, s.string()],
        accountKey: [null, s.publicKey()],
        totalShares: [null, s.u64()],
        totalMembers: [null, s.u64()],
        totalInflow: [null, s.u64()],
        lastSnapshotAmount: [null, s.u64()],
        bumpSeed: [null, s.u8()],
        accountOwnerBumpSeed: [null, s.u8()],
        totalAvailableShares: [null, s.u64()],
        membershipModel: [null, (0, types_1.getMembershipModelSerializer)(context)],
        membershipMint: [null, s.option(s.publicKey())],
        totalStakedShares: [null, s.option(s.u64())],
    })
        .deserializeUsing((account) => deserializeFanout(context, account))
        .whereField('discriminator', [198, 246, 243, 191, 206, 255, 3, 247]);
}
exports.getFanoutGpaBuilder = getFanoutGpaBuilder;
function getFanoutSize() {
    return 300;
}
exports.getFanoutSize = getFanoutSize;
function findFanoutPda(context, seeds) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    return context.eddsa.findPda(programId, [
        s.string({ size: 'variable' }).serialize('fanout-config'),
        s.string({ size: 'variable' }).serialize(seeds.name),
    ]);
}
exports.findFanoutPda = findFanoutPda;
//# sourceMappingURL=fanout.js.map