"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addMemberWallet = exports.getAddMemberWalletInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getAddMemberWalletInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['shares', s.u64()],
    ], { description: 'AddMemberWalletInstructionData' }), (value) => ({
        ...value,
        discriminator: [201, 9, 59, 128, 69, 117, 220, 235],
    }));
}
exports.getAddMemberWalletInstructionDataSerializer = getAddMemberWalletInstructionDataSerializer;
function addMemberWallet(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    const authorityAccount = input.authority ?? context.identity;
    const memberAccount = input.member;
    const fanoutAccount = input.fanout;
    const membershipAccountAccount = input.membershipAccount ??
        (0, accounts_1.findFanoutMembershipVoucherPda)(context, {
            fanout: (0, umi_1.publicKey)(fanoutAccount),
            member: (0, umi_1.publicKey)(memberAccount),
        });
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, true),
    });
    keys.push({
        pubkey: memberAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(memberAccount, false),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: membershipAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getAddMemberWalletInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = (0, accounts_1.getFanoutMembershipVoucherSize)() + umi_1.ACCOUNT_HEADER_SIZE;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.addMemberWallet = addMemberWallet;
//# sourceMappingURL=addMemberWallet.js.map