"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.distributeNft = exports.getDistributeNftInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getDistributeNftInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['distributeForMint', s.bool()],
    ], { description: 'DistributeNftInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [108, 240, 68, 81, 144, 83, 58, 153],
    }));
}
exports.getDistributeNftInstructionDataSerializer = getDistributeNftInstructionDataSerializer;
function distributeNft(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    const payerAccount = input.payer ?? context.payer;
    const memberAccount = input.member;
    const membershipMintTokenAccountAccount = input.membershipMintTokenAccount;
    const membershipKeyAccount = input.membershipKey;
    const membershipVoucherAccount = input.membershipVoucher;
    const fanoutAccount = input.fanout;
    const holdingAccountAccount = input.holdingAccount;
    const fanoutForMintAccount = input.fanoutForMint;
    const fanoutForMintMembershipVoucherAccount = input.fanoutForMintMembershipVoucher;
    const fanoutMintAccount = input.fanoutMint;
    const fanoutMintMemberTokenAccountAccount = input.fanoutMintMemberTokenAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, false),
    });
    keys.push({
        pubkey: memberAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(memberAccount, true),
    });
    keys.push({
        pubkey: membershipMintTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipMintTokenAccountAccount, true),
    });
    keys.push({
        pubkey: membershipKeyAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipKeyAccount, false),
    });
    keys.push({
        pubkey: membershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: holdingAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(holdingAccountAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutForMintAccount, true),
    });
    keys.push({
        pubkey: fanoutForMintMembershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutForMintMembershipVoucherAccount, true),
    });
    keys.push({
        pubkey: fanoutMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutMintAccount, false),
    });
    keys.push({
        pubkey: fanoutMintMemberTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutMintMemberTokenAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getDistributeNftInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.distributeNft = distributeNft;
//# sourceMappingURL=distributeNft.js.map