"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = exports.getInitInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getInitInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['bumpSeed', s.u8()],
        ['nativeAccountBumpSeed', s.u8()],
        ['name', s.string()],
        ['totalShares', s.u64()],
        ['model', (0, types_1.getMembershipModelSerializer)(context)],
    ], { description: 'InitInstructionData' }), (value) => ({
        ...value,
        discriminator: [172, 5, 165, 143, 86, 159, 50, 237],
    }));
}
exports.getInitInstructionDataSerializer = getInitInstructionDataSerializer;
function init(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    const authorityAccount = input.authority ?? context.identity;
    const fanoutAccount = input.fanout ?? (0, accounts_1.findFanoutPda)(context, { name: input.name });
    const holdingAccountAccount = input.holdingAccount ??
        (0, hooked_1.findFanoutNativeAccountPda)(context, { fanout: (0, umi_1.publicKey)(fanoutAccount) });
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const membershipMintAccount = input.membershipMint ??
        (0, umi_1.publicKey)('So11111111111111111111111111111111111111112');
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: holdingAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(holdingAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: membershipMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipMintAccount, true),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getInitInstructionDataSerializer(context).serialize({
        ...input,
        bumpSeed: fanoutAccount.bump,
        nativeAccountBumpSeed: holdingAccountAccount.bump,
    });
    const bytesCreatedOnChain = 557;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.init = init;
//# sourceMappingURL=init.js.map