"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferShares = exports.getTransferSharesInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getTransferSharesInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.array(s.u8(), { size: 8 })],
        ['shares', s.u64()],
    ], { description: 'TransferSharesInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [195, 175, 36, 50, 101, 22, 28, 87],
    }));
}
exports.getTransferSharesInstructionDataSerializer = getTransferSharesInstructionDataSerializer;
function transferShares(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    const authorityAccount = input.authority ?? context.identity;
    const fromMemberAccount = input.fromMember;
    const toMemberAccount = input.toMember;
    const fanoutAccount = input.fanout;
    const fromMembershipAccountAccount = input.fromMembershipAccount;
    const toMembershipAccountAccount = input.toMembershipAccount;
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    keys.push({
        pubkey: fromMemberAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fromMemberAccount, false),
    });
    keys.push({
        pubkey: toMemberAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(toMemberAccount, false),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: fromMembershipAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fromMembershipAccountAccount, true),
    });
    keys.push({
        pubkey: toMembershipAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(toMembershipAccountAccount, true),
    });
    const data = getTransferSharesInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.transferShares = transferShares;
//# sourceMappingURL=transferShares.js.map