"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.unstake = exports.getUnstakeInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getUnstakeInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.array(s.u8(), { size: 8 })]], { description: 'UnstakeInstructionArgs' }), (value) => ({
        ...value,
        discriminator: [217, 160, 136, 174, 149, 62, 79, 133],
    }));
}
exports.getUnstakeInstructionDataSerializer = getUnstakeInstructionDataSerializer;
function unstake(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplHydra', 'hyDQ4Nz1eYyegS6JfenyKwKzYxRsCWCriYSAjtzP4Vg');
    const memberAccount = input.member;
    const fanoutAccount = input.fanout;
    const membershipVoucherAccount = input.membershipVoucher;
    const membershipMintAccount = input.membershipMint;
    const membershipMintTokenAccountAccount = input.membershipMintTokenAccount;
    const memberStakeAccountAccount = input.memberStakeAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const instructionsAccount = input.instructions;
    signers.push(memberAccount);
    keys.push({
        pubkey: memberAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(memberAccount, true),
    });
    keys.push({
        pubkey: fanoutAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(fanoutAccount, true),
    });
    keys.push({
        pubkey: membershipVoucherAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipVoucherAccount, true),
    });
    keys.push({
        pubkey: membershipMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipMintAccount, true),
    });
    keys.push({
        pubkey: membershipMintTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(membershipMintTokenAccountAccount, true),
    });
    keys.push({
        pubkey: memberStakeAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(memberStakeAccountAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: instructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(instructionsAccount, false),
    });
    const data = getUnstakeInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.unstake = unstake;
//# sourceMappingURL=unstake.js.map